#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 selective
version:              0.4.2
visibility:           public
id:                   selective-0.4.2-DHHO3QmhPGr2Y4OL97lqR4
key:                  selective-0.4.2-DHHO3QmhPGr2Y4OL97lqR4
license:              MIT
copyright:            Andrey Mokhov, 2018-2021
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://www.staff.ncl.ac.uk/andrey.mokhov/selective-functors.pdf this paper>.

category:             Control
abi:                  1037238e8a061757412badae0addbbf3
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer

import-dirs:          /usr/lib/ghc-8.10.5/site-local/selective-0.4.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/selective-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/selective-0.4.2
hs-libraries:         HSselective-0.4.2-DHHO3QmhPGr2Y4OL97lqR4
depends:              base-4.14.2.0 containers-0.6.4.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

